"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, destination_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified destination, and eventually disables all the subscription filters that publish to it. This operation does not delete the physical resource encapsulated by the destination.

    Args:
        destination_name(str): The name of the destination.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.destination.init.delete(ctx, destination_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.destination.init.delete destination_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="delete_destination",
        op_kwargs={"destinationName": destination_name},
    )


async def describe_all(
    hub,
    ctx,
    destination_name_prefix: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all your destinations. The results are ASCII-sorted by destination name.

    Args:
        destination_name_prefix(str, optional): The prefix to match. If you don't specify a value, no prefix filter is applied. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of items returned. If you don't specify a value, the default is up to 50 items. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.destination.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.destination.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="describe_destinations",
        op_kwargs={
            "DestinationNamePrefix": destination_name_prefix,
            "nextToken": next_token,
            "limit": limit,
        },
    )


async def put(hub, ctx, destination_name: str, target_arn: str, role_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a destination. This operation is used only to create destinations for cross-account subscriptions. A destination encapsulates a physical resource (such as an Amazon Kinesis stream) and enables you to subscribe to a real-time stream of log events for a different account, ingested using PutLogEvents. Through an access policy, a destination controls what is written to it. By default, PutDestination does not set any access policy with the destination, which means a cross-account user cannot call PutSubscriptionFilter against this destination. To enable this, the destination owner must call PutDestinationPolicy after PutDestination. To perform a PutDestination operation, you must also have the iam:PassRole permission.

    Args:
        destination_name(str): A name for the destination.
        target_arn(str): The ARN of an Amazon Kinesis stream to which to deliver matching log events.
        role_arn(str): The ARN of an IAM role that grants CloudWatch Logs permissions to call the Amazon Kinesis PutRecord operation on the destination stream.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.destination.init.put(
                ctx, destination_name=value, target_arn=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.destination.init.put destination_name=value, target_arn=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="put_destination",
        op_kwargs={
            "destinationName": destination_name,
            "targetArn": target_arn,
            "roleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    custom_availability_zone_name: str,
    existing_vpn_id: str = None,
    new_vpn_tunnel_name: str = None,
    vpn_tunnel_originator_ip: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a custom Availability Zone (AZ). A custom AZ is an on-premises AZ that is integrated with a VMware vSphere cluster. For more information about RDS on VMware, see the  RDS on VMware User Guide.

    Args:
        custom_availability_zone_name(str): The name of the custom Availability Zone (AZ).
        existing_vpn_id(str, optional): The ID of an existing virtual private network (VPN) between the Amazon RDS website and the VMware vSphere cluster. Defaults to None.
        new_vpn_tunnel_name(str, optional): The name of a new VPN tunnel between the Amazon RDS website and the VMware vSphere cluster. Specify this parameter only if ExistingVpnId isn't specified. Defaults to None.
        vpn_tunnel_originator_ip(str, optional): The IP address of network traffic from your on-premises data center. A custom AZ receives the network traffic. Specify this parameter only if ExistingVpnId isn't specified. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.custom_availability_zone.create(
                ctx, custom_availability_zone_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.custom_availability_zone.create custom_availability_zone_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="create_custom_availability_zone",
        op_kwargs={
            "CustomAvailabilityZoneName": custom_availability_zone_name,
            "ExistingVpnId": existing_vpn_id,
            "NewVpnTunnelName": new_vpn_tunnel_name,
            "VpnTunnelOriginatorIP": vpn_tunnel_originator_ip,
        },
    )


async def delete(hub, ctx, custom_availability_zone_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a custom Availability Zone (AZ). A custom AZ is an on-premises AZ that is integrated with a VMware vSphere cluster. For more information about RDS on VMware, see the  RDS on VMware User Guide.

    Args:
        custom_availability_zone_id(str): The custom AZ identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.custom_availability_zone.delete(
                ctx, custom_availability_zone_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.custom_availability_zone.delete custom_availability_zone_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_custom_availability_zone",
        op_kwargs={"CustomAvailabilityZoneId": custom_availability_zone_id},
    )


async def describe_all(
    hub,
    ctx,
    custom_availability_zone_id: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about custom Availability Zones (AZs). A custom AZ is an on-premises AZ that is integrated with a VMware vSphere cluster. For more information about RDS on VMware, see the  RDS on VMware User Guide.

    Args:
        custom_availability_zone_id(str, optional): The custom AZ identifier. If this parameter is specified, information from only the specific custom AZ is returned. Defaults to None.
        filters(List, optional): A filter that specifies one or more custom AZs to describe. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous DescribeCustomAvailabilityZones request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.custom_availability_zone.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.custom_availability_zone.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_custom_availability_zones",
        op_kwargs={
            "CustomAvailabilityZoneId": custom_availability_zone_id,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, app_instance_admin_arn: str, app_instance_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Promotes an AppInstanceUser to an AppInstanceAdmin. The promoted user can perform the following actions.     ChannelModerator actions across all channels in the AppInstance.    DeleteChannelMessage actions.   Only an AppInstanceUser can be promoted to an AppInstanceAdmin role.

    Args:
        app_instance_admin_arn(str): The ARN of the administrator of the current AppInstance.
        app_instance_arn(str): The ARN of the AppInstance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.admin.create(
                ctx, app_instance_admin_arn=value, app_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.admin.create app_instance_admin_arn=value, app_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_app_instance_admin",
        op_kwargs={
            "AppInstanceAdminArn": app_instance_admin_arn,
            "AppInstanceArn": app_instance_arn,
        },
    )


async def delete(hub, ctx, app_instance_admin_arn: str, app_instance_arn: str) -> None:
    r"""
    **Autogenerated function**

    Demotes an AppInstanceAdmin to an AppInstanceUser. This action does not delete the user.

    Args:
        app_instance_admin_arn(str): The ARN of the AppInstance's administrator.
        app_instance_arn(str): The ARN of the AppInstance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.admin.delete(
                ctx, app_instance_admin_arn=value, app_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.admin.delete app_instance_admin_arn=value, app_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_app_instance_admin",
        op_kwargs={
            "AppInstanceAdminArn": app_instance_admin_arn,
            "AppInstanceArn": app_instance_arn,
        },
    )


async def describe(
    hub, ctx, app_instance_admin_arn: str, app_instance_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the full details of an AppInstanceAdmin.

    Args:
        app_instance_admin_arn(str): The ARN of the AppInstanceAdmin.
        app_instance_arn(str): The ARN of the AppInstance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.admin.describe(
                ctx, app_instance_admin_arn=value, app_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.admin.describe app_instance_admin_arn=value, app_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="describe_app_instance_admin",
        op_kwargs={
            "AppInstanceAdminArn": app_instance_admin_arn,
            "AppInstanceArn": app_instance_arn,
        },
    )


async def list_all(
    hub, ctx, app_instance_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the administrators in the AppInstance.

    Args:
        app_instance_arn(str): The ARN of the AppInstance.
        max_results(int, optional): The maximum number of administrators that you want to return. Defaults to None.
        next_token(str, optional): The token returned from previous API requests until the number of administrators is reached. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.admin.list_all(ctx, app_instance_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.admin.list_all app_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_app_instance_admins",
        op_kwargs={
            "AppInstanceArn": app_instance_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, finding_arns: List, locale: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the findings that are specified by the ARNs of the findings.

    Args:
        finding_arns(List): The ARN that specifies the finding that you want to describe.
        locale(str, optional): The locale into which you want to translate a finding description, recommendation, and the short description that identifies the finding. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.finding.describe_all(ctx, finding_arns=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.finding.describe_all finding_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="describe_findings",
        op_kwargs={"findingArns": finding_arns, "locale": locale},
    )


async def list_all(
    hub,
    ctx,
    assessment_run_arns: List = None,
    filter_: Dict = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.

    Args:
        assessment_run_arns(List, optional): The ARNs of the assessment runs that generate the findings that you want to list. Defaults to None.
        filter_(Dict, optional): You can use this parameter to specify a subset of data to be included in the action's response. For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListFindings action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.finding.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.finding.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="list_findings",
        op_kwargs={
            "assessmentRunArns": assessment_run_arns,
            "filter": filter_,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def mark(hub, ctx, source_server_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Archives specific Source Servers by setting the SourceServer.isArchived property to true for specified SourceServers by ID. This command only works for SourceServers with a lifecycle.state which equals DISCONNECTED or CUTOVER.

    Args:
        source_server_id(str): Mark as archived by Source Server ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.as_archived.mark(ctx, source_server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.as_archived.mark source_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="mark_as_archived",
        op_kwargs={"sourceServerID": source_server_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, account_id: str, bucket: str) -> None:
    r"""
    **Autogenerated function**

     This action deletes an Amazon S3 on Outposts bucket's lifecycle configuration. To delete an S3 bucket's lifecycle configuration, see DeleteBucketLifecycle in the Amazon S3 API Reference.   Deletes the lifecycle configuration from the specified Outposts bucket. Amazon S3 on Outposts removes all the lifecycle configuration rules in the lifecycle subresource associated with the bucket. Your objects never expire, and Amazon S3 on Outposts no longer automatically deletes any objects on the basis of rules contained in the deleted lifecycle configuration. For more information, see Using Amazon S3 on Outposts in Amazon S3 User Guide. To use this action, you must have permission to perform the s3-outposts:DeleteLifecycleConfiguration action. By default, the bucket owner has this permission and the Outposts bucket owner can grant this permission to others. All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. For more information about object expiration, see Elements to Describe Lifecycle Actions. Related actions include:    PutBucketLifecycleConfiguration     GetBucketLifecycleConfiguration

    Args:
        account_id(str): The account ID of the lifecycle configuration to delete.
        bucket(str): Specifies the bucket. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.lifecycle_configuration.delete(
                ctx, account_id=value, bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.lifecycle_configuration.delete account_id=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_bucket_lifecycle_configuration",
        op_kwargs={"AccountId": account_id, "Bucket": bucket},
    )


async def get(hub, ctx, account_id: str, bucket: str) -> Dict:
    r"""
    **Autogenerated function**

     This action gets an Amazon S3 on Outposts bucket's lifecycle configuration. To get an S3 bucket's lifecycle configuration, see GetBucketLifecycleConfiguration in the Amazon S3 API Reference.   Returns the lifecycle configuration information set on the Outposts bucket. For more information, see Using Amazon S3 on Outposts and for information about lifecycle configuration, see  Object Lifecycle Management in Amazon S3 User Guide. To use this action, you must have permission to perform the s3-outposts:GetLifecycleConfiguration action. The Outposts bucket owner has this permission, by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources. All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section.  GetBucketLifecycleConfiguration has the following special error:   Error code: NoSuchLifecycleConfiguration    Description: The lifecycle configuration does not exist.   HTTP Status Code: 404 Not Found   SOAP Fault Code Prefix: Client     The following actions are related to GetBucketLifecycleConfiguration:    PutBucketLifecycleConfiguration     DeleteBucketLifecycleConfiguration

    Args:
        account_id(str): The account ID of the Outposts bucket.
        bucket(str): The Amazon Resource Name (ARN) of the bucket. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.lifecycle_configuration.get(
                ctx, account_id=value, bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.lifecycle_configuration.get account_id=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_bucket_lifecycle_configuration",
        op_kwargs={"AccountId": account_id, "Bucket": bucket},
    )


async def put(
    hub, ctx, account_id: str, bucket: str, lifecycle_configuration: Dict = None
) -> None:
    r"""
    **Autogenerated function**

     This action puts a lifecycle configuration to an Amazon S3 on Outposts bucket. To put a lifecycle configuration to an S3 bucket, see PutBucketLifecycleConfiguration in the Amazon S3 API Reference.   Creates a new lifecycle configuration for the S3 on Outposts bucket or replaces an existing lifecycle configuration. Outposts buckets only support lifecycle configurations that delete/expire objects after a certain period of time and abort incomplete multipart uploads.  All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. The following actions are related to PutBucketLifecycleConfiguration:    GetBucketLifecycleConfiguration     DeleteBucketLifecycleConfiguration

    Args:
        account_id(str): The account ID of the Outposts bucket.
        bucket(str): The name of the bucket for which to set the configuration.
        lifecycle_configuration(Dict, optional): Container for lifecycle rules. You can add as many as 1,000 rules. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.lifecycle_configuration.put(
                ctx, account_id=value, bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.lifecycle_configuration.put account_id=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="put_bucket_lifecycle_configuration",
        op_kwargs={
            "AccountId": account_id,
            "Bucket": bucket,
            "LifecycleConfiguration": lifecycle_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    schema_id: Dict,
    first_schema_version_number: Dict,
    second_schema_version_number: Dict,
    schema_diff_type: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Fetches the schema version difference in the specified difference type between two stored schema versions in the Schema Registry. This API allows you to compare two schema versions between two schema definitions under the same schema.

    Args:
        schema_id(Dict): This is a wrapper structure to contain schema identity fields. The structure contains:   SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. One of SchemaArn or SchemaName has to be provided.   SchemaId$SchemaName: The name of the schema. One of SchemaArn or SchemaName has to be provided.  .
        first_schema_version_number(Dict): The first of the two schema versions to be compared.
        second_schema_version_number(Dict): The second of the two schema versions to be compared.
        schema_diff_type(str): Refers to SYNTAX_DIFF, which is the currently supported diff type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schema.version.diff.get(
                ctx,
                schema_id=value,
                first_schema_version_number=value,
                second_schema_version_number=value,
                schema_diff_type=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schema.version.diff.get schema_id=value, first_schema_version_number=value, second_schema_version_number=value, schema_diff_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_schema_versions_diff",
        op_kwargs={
            "SchemaId": schema_id,
            "FirstSchemaVersionNumber": first_schema_version_number,
            "SecondSchemaVersionNumber": second_schema_version_number,
            "SchemaDiffType": schema_diff_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def advertise(hub, ctx, cidr: str) -> Dict:
    r"""
    **Autogenerated function**

    Advertises an IPv4 address range that is provisioned for use with your AWS resources through bring your own IP addresses (BYOIP). It can take a few minutes before traffic to the specified addresses starts routing to AWS because of propagation delays.  To stop advertising the BYOIP address range, use  WithdrawByoipCidr. For more information, see Bring Your Own IP Addresses (BYOIP) in the AWS Global Accelerator Developer Guide.

    Args:
        cidr(str): The address range, in CIDR notation. This must be the exact range that you provisioned. You can't advertise only a portion of the provisioned range.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.byoip_cidr.advertise(ctx, cidr=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.byoip_cidr.advertise cidr=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="advertise_byoip_cidr",
        op_kwargs={"Cidr": cidr},
    )


async def deprovision(hub, ctx, cidr: str) -> Dict:
    r"""
    **Autogenerated function**

    Releases the specified address range that you provisioned to use with your AWS resources through bring your own IP addresses (BYOIP) and deletes the corresponding address pool.  Before you can release an address range, you must stop advertising it by using WithdrawByoipCidr and you must not have any accelerators that are using static IP addresses allocated from its address range.  For more information, see Bring Your Own IP Addresses (BYOIP) in the AWS Global Accelerator Developer Guide.

    Args:
        cidr(str): The address range, in CIDR notation. The prefix must be the same prefix that you specified when you provisioned the address range.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.byoip_cidr.deprovision(ctx, cidr=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.byoip_cidr.deprovision cidr=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="deprovision_byoip_cidr",
        op_kwargs={"Cidr": cidr},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the IP address ranges that were specified in calls to ProvisionByoipCidr, including the current state and a history of state changes.

    Args:
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.byoip_cidr.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.byoip_cidr.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="list_byoip_cidrs",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def provision(hub, ctx, cidr: str, cidr_authorization_context: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Provisions an IP address range to use with your AWS resources through bring your own IP addresses (BYOIP) and creates a corresponding address pool. After the address range is provisioned, it is ready to be advertised using  AdvertiseByoipCidr. For more information, see Bring Your Own IP Addresses (BYOIP) in the AWS Global Accelerator Developer Guide.

    Args:
        cidr(str): The public IPv4 address range, in CIDR notation. The most specific IP prefix that you can specify is /24. The address range cannot overlap with another address range that you've brought to this or another Region.
        cidr_authorization_context(Dict): A signed document that proves that you are authorized to bring the specified IP address range to Amazon using BYOIP. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.byoip_cidr.provision(
                ctx, cidr=value, cidr_authorization_context=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.byoip_cidr.provision cidr=value, cidr_authorization_context=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="provision_byoip_cidr",
        op_kwargs={
            "Cidr": cidr,
            "CidrAuthorizationContext": cidr_authorization_context,
        },
    )


async def withdraw(hub, ctx, cidr: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops advertising an address range that is provisioned as an address pool. You can perform this operation at most once every 10 seconds, even if you specify different address ranges each time. It can take a few minutes before traffic to the specified addresses stops routing to AWS because of propagation delays. For more information, see Bring Your Own IP Addresses (BYOIP) in the AWS Global Accelerator Developer Guide.

    Args:
        cidr(str): The address range, in CIDR notation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.byoip_cidr.withdraw(ctx, cidr=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.byoip_cidr.withdraw cidr=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="withdraw_byoip_cidr",
        op_kwargs={"Cidr": cidr},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub, ctx, account_id: str, room_id: str, membership_item_list: List
) -> Dict:
    r"""
    **Autogenerated function**

    Adds up to 50 members to a chat room in an Amazon Chime Enterprise account. Members can be users or bots. The member role designates whether the member is a chat room administrator or a general chat room member.

    Args:
        account_id(str): The Amazon Chime account ID.
        room_id(str): The room ID.
        membership_item_list(List): The list of membership items.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.create.room_membership.batch(
                ctx, account_id=value, room_id=value, membership_item_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.create.room_membership.batch account_id=value, room_id=value, membership_item_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="batch_create_room_membership",
        op_kwargs={
            "AccountId": account_id,
            "RoomId": room_id,
            "MembershipItemList": membership_item_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def restore(
    hub,
    ctx,
    db_cluster_identifier: str,
    source_db_cluster_identifier: str,
    restore_type: str = None,
    restore_to_time: str = None,
    use_latest_restorable_time: bool = None,
    port: int = None,
    db_subnet_group_name: str = None,
    option_group_name: str = None,
    vpc_security_group_ids: List = None,
    tags: List = None,
    kms_key_id: str = None,
    enable_iam_database_authentication: bool = None,
    backtrack_window: int = None,
    enable_cloudwatch_logs_exports: List = None,
    db_cluster_parameter_group_name: str = None,
    deletion_protection: bool = None,
    copy_tags_to_snapshot: bool = None,
    domain: str = None,
    domain_iam_role_name: str = None,
    scaling_configuration: Dict = None,
    engine_mode: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Restores a DB cluster to an arbitrary point in time. Users can restore to any point in time before LatestRestorableTime for up to BackupRetentionPeriod days. The target DB cluster is created from the source DB cluster with the same configuration as the original DB cluster, except that the new DB cluster is created with the default DB security group.   This action only restores the DB cluster, not the DB instances for that DB cluster. You must invoke the CreateDBInstance action to create DB instances for the restored DB cluster, specifying the identifier of the restored DB cluster in DBClusterIdentifier. You can create DB instances only after the RestoreDBClusterToPointInTime action has completed and the DB cluster is available.  For more information on Amazon Aurora, see  What Is Amazon Aurora? in the Amazon Aurora User Guide.   This action only applies to Aurora DB clusters.

    Args:
        db_cluster_identifier(str): The name of the new DB cluster to be created. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens   First character must be a letter   Can't end with a hyphen or contain two consecutive hyphens  .
        restore_type(str, optional): The type of restore to be performed. You can specify one of the following values:    full-copy - The new DB cluster is restored as a full copy of the source DB cluster.    copy-on-write - The new DB cluster is restored as a clone of the source DB cluster.   Constraints: You can't specify copy-on-write if the engine version of the source DB cluster is earlier than 1.11. If you don't specify a RestoreType value, then the new DB cluster is restored as a full copy of the source DB cluster. Defaults to None.
        source_db_cluster_identifier(str): The identifier of the source DB cluster from which to restore. Constraints:   Must match the identifier of an existing DBCluster.  .
        restore_to_time(str, optional): The date and time to restore the DB cluster to. Valid Values: Value must be a time in Universal Coordinated Time (UTC) format Constraints:   Must be before the latest restorable time for the DB instance   Must be specified if UseLatestRestorableTime parameter isn't provided   Can't be specified if the UseLatestRestorableTime parameter is enabled   Can't be specified if the RestoreType parameter is copy-on-write    Example: 2015-03-07T23:45:00Z . Defaults to None.
        use_latest_restorable_time(bool, optional): A value that indicates whether to restore the DB cluster to the latest restorable backup time. By default, the DB cluster isn't restored to the latest restorable backup time.  Constraints: Can't be specified if RestoreToTime parameter is provided. Defaults to None.
        port(int, optional): The port number on which the new DB cluster accepts connections. Constraints: A value from 1150-65535.  Default: The default port for the engine. Defaults to None.
        db_subnet_group_name(str, optional): The DB subnet group name to use for the new DB cluster. Constraints: If supplied, must match the name of an existing DBSubnetGroup. Example: mySubnetgroup . Defaults to None.
        option_group_name(str, optional): The name of the option group for the new DB cluster. Defaults to None.
        vpc_security_group_ids(List, optional): A list of VPC security groups that the new DB cluster belongs to. Defaults to None.
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.
        kms_key_id(str, optional): The Amazon Web Services KMS key identifier to use when restoring an encrypted DB cluster from an encrypted DB cluster. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the Amazon Web Services KMS customer master key (CMK). To use a CMK in a different Amazon Web Services account, specify the key ARN or alias ARN. You can restore to a new DB cluster and encrypt the new DB cluster with a Amazon Web Services KMS CMK that is different than the Amazon Web Services KMS key used to encrypt the source DB cluster. The new DB cluster is encrypted with the Amazon Web Services KMS CMK identified by the KmsKeyId parameter. If you don't specify a value for the KmsKeyId parameter, then the following occurs:   If the DB cluster is encrypted, then the restored DB cluster is encrypted using the Amazon Web Services KMS CMK that was used to encrypt the source DB cluster.   If the DB cluster isn't encrypted, then the restored DB cluster isn't encrypted.   If DBClusterIdentifier refers to a DB cluster that isn't encrypted, then the restore request is rejected. Defaults to None.
        enable_iam_database_authentication(bool, optional): A value that indicates whether to enable mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts. By default, mapping is disabled. For more information, see  IAM Database Authentication in the Amazon Aurora User Guide. . Defaults to None.
        backtrack_window(int, optional): The target backtrack window, in seconds. To disable backtracking, set this value to 0.  Currently, Backtrack is only supported for Aurora MySQL DB clusters.  Default: 0 Constraints:   If specified, this value must be set to a number from 0 to 259,200 (72 hours).  . Defaults to None.
        enable_cloudwatch_logs_exports(List, optional): The list of logs that the restored DB cluster is to export to CloudWatch Logs. The values in the list depend on the DB engine being used. For more information, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon Aurora User Guide. Defaults to None.
        db_cluster_parameter_group_name(str, optional): The name of the DB cluster parameter group to associate with this DB cluster. If this argument is omitted, the default DB cluster parameter group for the specified engine is used. Constraints:   If supplied, must match the name of an existing DB cluster parameter group.   Must be 1 to 255 letters, numbers, or hyphens.   First character must be a letter.   Can't end with a hyphen or contain two consecutive hyphens.  . Defaults to None.
        deletion_protection(bool, optional): A value that indicates whether the DB cluster has deletion protection enabled. The database can't be deleted when deletion protection is enabled. By default, deletion protection is disabled. . Defaults to None.
        copy_tags_to_snapshot(bool, optional): A value that indicates whether to copy all tags from the restored DB cluster to snapshots of the restored DB cluster. The default is not to copy them. Defaults to None.
        domain(str, optional): Specify the Active Directory directory ID to restore the DB cluster in. The domain must be created prior to this operation.   For Amazon Aurora DB clusters, Amazon RDS can use Kerberos Authentication to authenticate users that connect to the DB cluster. For more information, see Kerberos Authentication in the Amazon Aurora User Guide. . Defaults to None.
        domain_iam_role_name(str, optional): Specify the name of the IAM role to be used when making API calls to the Directory Service. Defaults to None.
        scaling_configuration(Dict, optional): For DB clusters in serverless DB engine mode, the scaling properties of the DB cluster. Defaults to None.
        engine_mode(str, optional): The engine mode of the new cluster. Specify provisioned or serverless, depending on the type of the cluster you are creating. You can create an Aurora Serverless clone from a provisioned cluster, or a provisioned clone from an Aurora Serverless cluster. To create a clone that is an Aurora Serverless cluster, the original cluster must be an Aurora Serverless cluster or an encrypted provisioned cluster. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.cluster.to_point_in_time.restore(
                ctx, db_cluster_identifier=value, source_db_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.cluster.to_point_in_time.restore db_cluster_identifier=value, source_db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="restore_db_cluster_to_point_in_time",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "RestoreType": restore_type,
            "SourceDBClusterIdentifier": source_db_cluster_identifier,
            "RestoreToTime": restore_to_time,
            "UseLatestRestorableTime": use_latest_restorable_time,
            "Port": port,
            "DBSubnetGroupName": db_subnet_group_name,
            "OptionGroupName": option_group_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "Tags": tags,
            "KmsKeyId": kms_key_id,
            "EnableIAMDatabaseAuthentication": enable_iam_database_authentication,
            "BacktrackWindow": backtrack_window,
            "EnableCloudwatchLogsExports": enable_cloudwatch_logs_exports,
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "DeletionProtection": deletion_protection,
            "CopyTagsToSnapshot": copy_tags_to_snapshot,
            "Domain": domain,
            "DomainIAMRoleName": domain_iam_role_name,
            "ScalingConfiguration": scaling_configuration,
            "EngineMode": engine_mode,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "property"


async def modify(hub, ctx, workspace_id: str, workspace_properties: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified WorkSpace properties. For important information about how to modify the size of the root and user volumes, see  Modify a WorkSpace.

    Args:
        workspace_id(str): The identifier of the WorkSpace.
        workspace_properties(Dict): The properties of the WorkSpace.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.property_.modify(
                ctx, workspace_id=value, workspace_properties=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.property.modify workspace_id=value, workspace_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="modify_workspace_properties",
        op_kwargs={
            "WorkspaceId": workspace_id,
            "WorkspaceProperties": workspace_properties,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, names: List = None, marker: str = None, page_size: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified policies or all policies used for SSL negotiation. For more information, see Security policies in the Application Load Balancers Guide or Security policies in the Network Load Balancers Guide.

    Args:
        names(List, optional): The names of the policies. Defaults to None.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        page_size(int, optional): The maximum number of results to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.ssl_policy.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.ssl_policy.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="describe_ssl_policies",
        op_kwargs={"Names": names, "Marker": marker, "PageSize": page_size},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, schema: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Personalize schema from the specified schema string. The schema you create must be in Avro JSON format. Amazon Personalize recognizes three schema variants. Each schema is associated with a dataset type and has a set of required field and keywords. You specify a schema when you call CreateDataset.  Related APIs     ListSchemas     DescribeSchema     DeleteSchema

    Args:
        name(str): The name for the schema.
        schema(str): A schema in Avro JSON format.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.schema.create(ctx, name=value, schema=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.schema.create name=value, schema=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="create_schema",
        op_kwargs={"name": name, "schema": schema},
    )


async def delete(hub, ctx, schema_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a schema. Before deleting a schema, you must delete all datasets referencing the schema. For more information on schemas, see CreateSchema.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) of the schema to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.schema.delete(ctx, schema_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.schema.delete schema_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="delete_schema",
        op_kwargs={"schemaArn": schema_arn},
    )


async def describe(hub, ctx, schema_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a schema. For more information on schemas, see CreateSchema.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) of the schema to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.schema.describe(ctx, schema_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.schema.describe schema_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_schema",
        op_kwargs={"schemaArn": schema_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, bucket_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new access key for the specified Amazon Lightsail bucket. Access keys consist of an access key ID and corresponding secret access key. Access keys grant full programmatic access to the specified bucket and its objects. You can have a maximum of two access keys per bucket. Use the GetBucketAccessKeys action to get a list of current access keys for a specific bucket. For more information about access keys, see Creating access keys for a bucket in Amazon Lightsail in the Amazon Lightsail Developer Guide.  The secretAccessKey value is returned only in response to the CreateBucketAccessKey action. You can get a secret access key only when you first create an access key; you cannot get the secret access key later. If you lose the secret access key, you must create a new access key.

    Args:
        bucket_name(str): The name of the bucket that the new access key will belong to, and grant access to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.bucket.access_key.create(ctx, bucket_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.bucket.access_key.create bucket_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_bucket_access_key",
        op_kwargs={"bucketName": bucket_name},
    )


async def delete(hub, ctx, bucket_name: str, access_key_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an access key for the specified Amazon Lightsail bucket. We recommend that you delete an access key if the secret access key is compromised. For more information about access keys, see Creating access keys for a bucket in Amazon Lightsail in the Amazon Lightsail Developer Guide.

    Args:
        bucket_name(str): The name of the bucket that the access key belongs to.
        access_key_id(str): The ID of the access key to delete. Use the GetBucketAccessKeys action to get a list of access key IDs that you can specify.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.bucket.access_key.delete(
                ctx, bucket_name=value, access_key_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.bucket.access_key.delete bucket_name=value, access_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_bucket_access_key",
        op_kwargs={"bucketName": bucket_name, "accessKeyId": access_key_id},
    )


async def get_all(hub, ctx, bucket_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the existing access key IDs for the specified Amazon Lightsail bucket.  This action does not return the secret access key value of an access key. You can get a secret access key only when you create it from the response of the CreateBucketAccessKey action. If you lose the secret access key, you must create a new access key.

    Args:
        bucket_name(str): The name of the bucket for which to return access keys.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.bucket.access_key.get_all(ctx, bucket_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.bucket.access_key.get_all bucket_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_bucket_access_keys",
        op_kwargs={"bucketName": bucket_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def assign(
    hub,
    ctx,
    network_interface_id: str,
    ipv6_address_count: int = None,
    ipv6_addresses: List = None,
    ipv6_prefix_count: int = None,
    ipv6_prefixes: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Assigns one or more IPv6 addresses to the specified network interface. You can specify one or more specific IPv6 addresses, or you can specify the number of IPv6 addresses to be automatically assigned from within the subnet's IPv6 CIDR block range. You can assign as many IPv6 addresses to a network interface as you can assign private IPv4 addresses, and the limit varies per instance type. For information, see IP Addresses Per Network Interface Per Instance Type in the Amazon Elastic Compute Cloud User Guide. You must specify either the IPv6 addresses or the IPv6 address count in the request.  You can optionally use Prefix Delegation on the network interface. You must specify either the IPV6 Prefix Delegation prefixes, or the IPv6 Prefix Delegation count. For information, see Prefix Delegation in the Amazon Elastic Compute Cloud User Guide.

    Args:
        ipv6_address_count(int, optional): The number of additional IPv6 addresses to assign to the network interface. The specified number of IPv6 addresses are assigned in addition to the existing IPv6 addresses that are already assigned to the network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can't use this option if specifying specific IPv6 addresses. Defaults to None.
        ipv6_addresses(List, optional): One or more specific IPv6 addresses to be assigned to the network interface. You can't use this option if you're specifying a number of IPv6 addresses. Defaults to None.
        ipv6_prefix_count(int, optional): The number of IPv6 Prefix Delegation prefixes that AWS automatically assigns to the network interface. You cannot use this option if you use the Ipv6Prefixes option. Defaults to None.
        ipv6_prefixes(List, optional): One or more IPv6 Prefix Delegation prefixes assigned to the network interface. You cannot use this option if you use the Ipv6PrefixCount option. Defaults to None.
        network_interface_id(str): The ID of the network interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.ipv6.address.assign(ctx, network_interface_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.ipv6.address.assign network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="assign_ipv6_addresses",
        op_kwargs={
            "Ipv6AddressCount": ipv6_address_count,
            "Ipv6Addresses": ipv6_addresses,
            "Ipv6PrefixCount": ipv6_prefix_count,
            "Ipv6Prefixes": ipv6_prefixes,
            "NetworkInterfaceId": network_interface_id,
        },
    )


async def unassign(
    hub,
    ctx,
    network_interface_id: str,
    ipv6_addresses: List = None,
    ipv6_prefixes: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Unassigns one or more IPv6 addresses IPv4 Prefix Delegation prefixes from a network interface.

    Args:
        ipv6_addresses(List, optional): The IPv6 addresses to unassign from the network interface. Defaults to None.
        ipv6_prefixes(List, optional): One or moreIPv6 Prefix Delegation prefixes to unassign from the network interface. Defaults to None.
        network_interface_id(str): The ID of the network interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.ipv6.address.unassign(ctx, network_interface_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.ipv6.address.unassign network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="unassign_ipv6_addresses",
        op_kwargs={
            "Ipv6Addresses": ipv6_addresses,
            "Ipv6Prefixes": ipv6_prefixes,
            "NetworkInterfaceId": network_interface_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, type_: str, hosted_zone_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the specified limit for a specified hosted zone, for example, the maximum number of records that you can create in the hosted zone.  For the default limit, see Limits in the Amazon Route 53 Developer Guide. To request a higher limit, open a case.

    Args:
        type_(str): The limit that you want to get. Valid values include the following:    MAX_RRSETS_BY_ZONE: The maximum number of records that you can create in the specified hosted zone.    MAX_VPCS_ASSOCIATED_BY_ZONE: The maximum number of Amazon VPCs that you can associate with the specified private hosted zone.  .
        hosted_zone_id(str): The ID of the hosted zone that you want to get a limit for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.hosted_zone.limit.get(
                ctx, type_=value, hosted_zone_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.hosted_zone.limit.get type_=value, hosted_zone_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_hosted_zone_limit",
        op_kwargs={"Type": type_, "HostedZoneId": hosted_zone_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    admin_role_arn: str,
    display_name: str,
    studio_name: str,
    user_role_arn: str,
    client_token: str = None,
    studio_encryption_configuration: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new Studio. When creating a Studio, two IAM roles must be provided: the admin role and the user Role. These roles are assumed by your users when they log in to the Nimble Studio portal. The user role must have the AmazonNimbleStudio-StudioUser managed policy attached for the portal to function properly. The Admin Role must have the AmazonNimbleStudio-StudioAdmin managed policy attached for the portal to function properly. You may optionally specify a KMS key in the StudioEncryptionConfiguration. In Nimble Studio, resource names, descriptions, initialization scripts, and other data you provide are always encrypted at rest using an AWS KMS key. By default, this key is owned by AWS and managed on your behalf. You may provide your own AWS KMS key when calling CreateStudio to encrypt this data using a key you own and manage. When providing an AWS KMS key during studio creation, Nimble Studio creates KMS grants in your account to provide your studio user and admin roles access to these KMS keys. If you delete this grant, the studio will no longer be accessible to your portal users. If you delete the studio KMS key, your studio will no longer be accessible.

    Args:
        admin_role_arn(str): The IAM role that Studio Admins will assume when logging in to the Nimble Studio portal.
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        display_name(str): A friendly name for the studio.
        studio_encryption_configuration(Dict, optional): The studio encryption configuration. Defaults to None.
        studio_name(str): The studio name that is used in the URL of the Nimble Studio portal when accessed by Nimble Studio users.
        tags(Dict, optional): A collection of labels, in the form of key:value pairs, that apply to this resource. Defaults to None.
        user_role_arn(str): The IAM role that Studio Users will assume when logging in to the Nimble Studio portal.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.init.create(
                ctx,
                admin_role_arn=value,
                display_name=value,
                studio_name=value,
                user_role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.init.create admin_role_arn=value, display_name=value, studio_name=value, user_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="create_studio",
        op_kwargs={
            "adminRoleArn": admin_role_arn,
            "clientToken": client_token,
            "displayName": display_name,
            "studioEncryptionConfiguration": studio_encryption_configuration,
            "studioName": studio_name,
            "tags": tags,
            "userRoleArn": user_role_arn,
        },
    )


async def delete(hub, ctx, studio_id: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Delete a studio resource.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.init.delete(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.init.delete studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="delete_studio",
        op_kwargs={"clientToken": client_token, "studioId": studio_id},
    )


async def get(hub, ctx, studio_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get a Studio resource.

    Args:
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.init.get(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.init.get studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="get_studio",
        op_kwargs={"studioId": studio_id},
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List studios in your AWS account in the requested AWS Region.

    Args:
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="list_studios",
        op_kwargs={"nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    studio_id: str,
    admin_role_arn: str = None,
    client_token: str = None,
    display_name: str = None,
    user_role_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update a Studio resource. Currently, this operation only supports updating the displayName of your studio.

    Args:
        admin_role_arn(str, optional): The IAM role that Studio Admins will assume when logging in to the Nimble Studio portal. Defaults to None.
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        display_name(str, optional): A friendly name for the studio. Defaults to None.
        studio_id(str): The studio ID.
        user_role_arn(str, optional): The IAM role that Studio Users will assume when logging in to the Nimble Studio portal. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.init.update(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.init.update studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="update_studio",
        op_kwargs={
            "adminRoleArn": admin_role_arn,
            "clientToken": client_token,
            "displayName": display_name,
            "studioId": studio_id,
            "userRoleArn": user_role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "property"


async def describe_all(
    hub,
    ctx,
    operating_system: str,
    property_: str,
    patch_set: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the properties of available patches organized by product, product family, classification, severity, and other properties of available patches. You can use the reported properties in the filters you specify in requests for operations such as CreatePatchBaseline, UpdatePatchBaseline, DescribeAvailablePatches, and DescribePatchBaselines. The following section lists the properties that can be used in filters for each major operating system type:  AMAZON_LINUX  Valid properties: PRODUCT | CLASSIFICATION | SEVERITY   AMAZON_LINUX_2  Valid properties: PRODUCT | CLASSIFICATION | SEVERITY   CENTOS  Valid properties: PRODUCT | CLASSIFICATION | SEVERITY   DEBIAN  Valid properties: PRODUCT | PRIORITY   MACOS  Valid properties: PRODUCT | CLASSIFICATION   ORACLE_LINUX  Valid properties: PRODUCT | CLASSIFICATION | SEVERITY   REDHAT_ENTERPRISE_LINUX  Valid properties: PRODUCT | CLASSIFICATION | SEVERITY   SUSE  Valid properties: PRODUCT | CLASSIFICATION | SEVERITY   UBUNTU  Valid properties: PRODUCT | PRIORITY   WINDOWS  Valid properties: PRODUCT | PRODUCT_FAMILY | CLASSIFICATION | MSRC_SEVERITY

    Args:
        operating_system(str): The operating system type for which to list patches.
        property_(str): The patch property for which you want to view patch details. .
        patch_set(str, optional): Indicates whether to list patches for the Windows operating system or for applications released by Microsoft. Not applicable for the Linux or macOS operating systems. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.patch.property_.describe_all(
                ctx, operating_system=value, property_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.patch.property.describe_all operating_system=value, property_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_patch_properties",
        op_kwargs={
            "OperatingSystem": operating_system,
            "Property": property_,
            "PatchSet": patch_set,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, field_level_encryption_profile_config: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Create a field-level encryption profile.

    Args:
        field_level_encryption_profile_config(Dict): The request to create a field-level encryption profile.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.field_level_encryption.profile.init.create(
                ctx, field_level_encryption_profile_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.field_level_encryption.profile.init.create field_level_encryption_profile_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="create_field_level_encryption_profile",
        op_kwargs={
            "FieldLevelEncryptionProfileConfig": field_level_encryption_profile_config
        },
    )


async def delete(hub, ctx, id_: str, if_match: str = None) -> None:
    r"""
    **Autogenerated function**

    Remove a field-level encryption profile.

    Args:
        id_(str): Request the ID of the profile you want to delete from CloudFront.
        if_match(str, optional): The value of the ETag header that you received when retrieving the profile to delete. For example: E2QWRUHAPOMQZL. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.field_level_encryption.profile.init.delete(
                ctx, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.field_level_encryption.profile.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="delete_field_level_encryption_profile",
        op_kwargs={"Id": id_, "IfMatch": if_match},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Get the field-level encryption profile information.

    Args:
        id_(str): Get the ID for the field-level encryption profile information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.field_level_encryption.profile.init.get(
                ctx, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.field_level_encryption.profile.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="get_field_level_encryption_profile",
        op_kwargs={"Id": id_},
    )


async def list_all(hub, ctx, marker: str = None, max_items: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Request a list of field-level encryption profiles that have been created in CloudFront for this account.

    Args:
        marker(str, optional): Use this when paginating results to indicate where to begin in your list of profiles. The results include profiles in the list that occur after the marker. To get the next page of results, set the Marker to the value of the NextMarker from the current page's response (which is also the ID of the last profile on that page). . Defaults to None.
        max_items(str, optional): The maximum number of field-level encryption profiles you want in the response body. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.field_level_encryption.profile.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.field_level_encryption.profile.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="list_field_level_encryption_profiles",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub,
    ctx,
    field_level_encryption_profile_config: Dict,
    id_: str,
    if_match: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update a field-level encryption profile.

    Args:
        field_level_encryption_profile_config(Dict): Request to update a field-level encryption profile. .
        id_(str): The ID of the field-level encryption profile request. .
        if_match(str, optional): The value of the ETag header that you received when retrieving the profile identity to update. For example: E2QWRUHAPOMQZL. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.field_level_encryption.profile.init.update(
                ctx, field_level_encryption_profile_config=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.field_level_encryption.profile.init.update field_level_encryption_profile_config=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="update_field_level_encryption_profile",
        op_kwargs={
            "FieldLevelEncryptionProfileConfig": field_level_encryption_profile_config,
            "Id": id_,
            "IfMatch": if_match,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    scaling_plan_name: str,
    application_source: Dict,
    scaling_instructions: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a scaling plan.

    Args:
        scaling_plan_name(str): The name of the scaling plan. Names cannot contain vertical bars, colons, or forward slashes.
        application_source(Dict): A CloudFormation stack or set of tags. You can create one scaling plan per application source. For more information, see ApplicationSource in the AWS Auto Scaling API Reference.
        scaling_instructions(List): The scaling instructions. For more information, see ScalingInstruction in the AWS Auto Scaling API Reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling_plan_scaling_plan.init.create(
                ctx, scaling_plan_name=value, application_source=value, scaling_instructions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling_plan_scaling_plan.init.create scaling_plan_name=value, application_source=value, scaling_instructions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling-plans",
        operation="create_scaling_plan",
        op_kwargs={
            "ScalingPlanName": scaling_plan_name,
            "ApplicationSource": application_source,
            "ScalingInstructions": scaling_instructions,
        },
    )


async def delete(hub, ctx, scaling_plan_name: str, scaling_plan_version: int) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified scaling plan. Deleting a scaling plan deletes the underlying ScalingInstruction for all of the scalable resources that are covered by the plan. If the plan has launched resources or has scaling activities in progress, you must delete those resources separately.

    Args:
        scaling_plan_name(str): The name of the scaling plan.
        scaling_plan_version(int): The version number of the scaling plan. Currently, the only valid value is 1.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling_plan_scaling_plan.init.delete(
                ctx, scaling_plan_name=value, scaling_plan_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling_plan_scaling_plan.init.delete scaling_plan_name=value, scaling_plan_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling-plans",
        operation="delete_scaling_plan",
        op_kwargs={
            "ScalingPlanName": scaling_plan_name,
            "ScalingPlanVersion": scaling_plan_version,
        },
    )


async def describe_all(
    hub,
    ctx,
    scaling_plan_names: List = None,
    scaling_plan_version: int = None,
    application_sources: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your scaling plans.

    Args:
        scaling_plan_names(List, optional): The names of the scaling plans (up to 10). If you specify application sources, you cannot specify scaling plan names. Defaults to None.
        scaling_plan_version(int, optional): The version number of the scaling plan. Currently, the only valid value is 1.  If you specify a scaling plan version, you must also specify a scaling plan name. . Defaults to None.
        application_sources(List, optional): The sources for the applications (up to 10). If you specify scaling plan names, you cannot specify application sources. Defaults to None.
        max_results(int, optional): The maximum number of scalable resources to return. This value can be between 1 and 50. The default value is 50. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling_plan_scaling_plan.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling_plan_scaling_plan.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling-plans",
        operation="describe_scaling_plans",
        op_kwargs={
            "ScalingPlanNames": scaling_plan_names,
            "ScalingPlanVersion": scaling_plan_version,
            "ApplicationSources": application_sources,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    scaling_plan_name: str,
    scaling_plan_version: int,
    application_source: Dict = None,
    scaling_instructions: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified scaling plan. You cannot update a scaling plan if it is in the process of being created, updated, or deleted.

    Args:
        scaling_plan_name(str): The name of the scaling plan.
        scaling_plan_version(int): The version number of the scaling plan. The only valid value is 1. Currently, you cannot have multiple scaling plan versions.
        application_source(Dict, optional): A CloudFormation stack or set of tags. For more information, see ApplicationSource in the AWS Auto Scaling API Reference. Defaults to None.
        scaling_instructions(List, optional): The scaling instructions. For more information, see ScalingInstruction in the AWS Auto Scaling API Reference. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling_plan_scaling_plan.init.update(
                ctx, scaling_plan_name=value, scaling_plan_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling_plan_scaling_plan.init.update scaling_plan_name=value, scaling_plan_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling-plans",
        operation="update_scaling_plan",
        op_kwargs={
            "ScalingPlanName": scaling_plan_name,
            "ScalingPlanVersion": scaling_plan_version,
            "ApplicationSource": application_source,
            "ScalingInstructions": scaling_instructions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    aws_account_id: str,
    theme_id: str,
    name: str,
    base_theme_id: str,
    configuration: Dict,
    version_description: str = None,
    permissions: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a theme. A theme is set of configuration options for color and layout. Themes apply to analyses and dashboards. For more information, see Using Themes in Amazon QuickSight in the Amazon QuickSight User Guide.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; where you want to store the new theme. .
        theme_id(str): An ID for the theme that you want to create. The theme ID is unique per Region; in each Amazon Web Services account;.
        name(str): A display name for the theme.
        base_theme_id(str): The ID of the theme that a custom theme will inherit from. All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use ListThemes or choose Themes from within a QuickSight analysis. .
        version_description(str, optional): A description of the first version of the theme that you're creating. Every time UpdateTheme is called, a new version is created. Each version of the theme has a description of the version in the VersionDescription field. Defaults to None.
        configuration(Dict): The theme configuration, which contains the theme display properties.
        permissions(List, optional): A valid grouping of resource permissions to apply to the new theme. . Defaults to None.
        tags(List, optional): A map of the key-value pairs for the resource tag or tags that you want to add to the resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.init.create(
                ctx,
                aws_account_id=value,
                theme_id=value,
                name=value,
                base_theme_id=value,
                configuration=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.init.create aws_account_id=value, theme_id=value, name=value, base_theme_id=value, configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_theme",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "ThemeId": theme_id,
            "Name": name,
            "BaseThemeId": base_theme_id,
            "VersionDescription": version_description,
            "Configuration": configuration,
            "Permissions": permissions,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, aws_account_id: str, theme_id: str, version_number: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a theme.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the theme that you're deleting.
        theme_id(str): An ID for the theme that you want to delete.
        version_number(int, optional): The version of the theme that you want to delete.   Note: If you don't provide a version number, you're using this call to DeleteTheme to delete all versions of the theme. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.init.delete(
                ctx, aws_account_id=value, theme_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.init.delete aws_account_id=value, theme_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_theme",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "ThemeId": theme_id,
            "VersionNumber": version_number,
        },
    )


async def describe(
    hub,
    ctx,
    aws_account_id: str,
    theme_id: str,
    version_number: int = None,
    alias_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a theme.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the theme that you're describing.
        theme_id(str): The ID for the theme.
        version_number(int, optional): The version number for the version to describe. If a VersionNumber parameter value isn't provided, the latest version of the theme is described. Defaults to None.
        alias_name(str, optional): The alias of the theme that you want to describe. If you name a specific alias, you describe the version that the alias points to. You can specify the latest version of the theme by providing the keyword $LATEST in the AliasName parameter. The keyword $PUBLISHED doesn't apply to themes. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.init.describe(
                ctx, aws_account_id=value, theme_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.init.describe aws_account_id=value, theme_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_theme",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "ThemeId": theme_id,
            "VersionNumber": version_number,
            "AliasName": alias_name,
        },
    )


async def list_all(
    hub,
    ctx,
    aws_account_id: str,
    next_token: str = None,
    max_results: int = None,
    type_: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the themes in the current Amazon Web Services account;.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the themes that you're listing.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.
        type_(str, optional): The type of themes that you want to list. Valid options include the following:    ALL (default)- Display all existing themes.    CUSTOM - Display only the themes created by people using Amazon QuickSight.    QUICKSIGHT - Display only the starting themes defined by Amazon QuickSight.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.init.list_all(ctx, aws_account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.init.list_all aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_themes",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "Type": type_,
        },
    )


async def update(
    hub,
    ctx,
    aws_account_id: str,
    theme_id: str,
    base_theme_id: str,
    name: str = None,
    version_description: str = None,
    configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a theme.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the theme that you're updating.
        theme_id(str): The ID for the theme.
        name(str, optional): The name for the theme. Defaults to None.
        base_theme_id(str): The theme ID, defined by Amazon QuickSight, that a custom theme inherits from. All themes initially inherit from a default Amazon QuickSight theme.
        version_description(str, optional): A description of the theme version that you're updating Every time that you call UpdateTheme, you create a new version of the theme. Each version of the theme maintains a description of the version in VersionDescription. Defaults to None.
        configuration(Dict, optional): The theme configuration, which contains the theme display properties. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.init.update(
                ctx, aws_account_id=value, theme_id=value, base_theme_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.init.update aws_account_id=value, theme_id=value, base_theme_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_theme",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "ThemeId": theme_id,
            "Name": name,
            "BaseThemeId": base_theme_id,
            "VersionDescription": version_description,
            "Configuration": configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides cluster-level details including status, hardware and software configuration, VPC settings, and so on.

    Args:
        cluster_id(str): The identifier of the cluster to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.cluster.describe(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.cluster.describe cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="describe_cluster",
        op_kwargs={"ClusterId": cluster_id},
    )


async def list_all(
    hub,
    ctx,
    created_after: str = None,
    created_before: str = None,
    cluster_states: List = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides the status of all clusters visible to this account. Allows you to filter the list of clusters based on certain criteria; for example, filtering by cluster creation date and time or by status. This call returns a maximum of 50 clusters in unsorted order per call, but returns a marker to track the paging of the cluster list across multiple ListClusters calls.

    Args:
        created_after(str, optional): The creation date and time beginning value filter for listing clusters. Defaults to None.
        created_before(str, optional): The creation date and time end value filter for listing clusters. Defaults to None.
        cluster_states(List, optional): The cluster state filters to apply when listing clusters. Clusters that change state while this action runs may be not be returned as expected in the list of clusters. Defaults to None.
        marker(str, optional): The pagination token that indicates the next set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.cluster.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.cluster.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="list_clusters",
        op_kwargs={
            "CreatedAfter": created_after,
            "CreatedBefore": created_before,
            "ClusterStates": cluster_states,
            "Marker": marker,
        },
    )


async def modify(hub, ctx, cluster_id: str, step_concurrency_level: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the number of steps that can be executed concurrently for the cluster specified using ClusterID.

    Args:
        cluster_id(str): The unique identifier of the cluster.
        step_concurrency_level(int, optional): The number of steps that can be executed concurrently. You can specify a minimum of 1 step and a maximum of 256 steps. We recommend that you do not change this parameter while steps are running or the ActionOnFailure setting may not behave as expected. For more information see Step$ActionOnFailure. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.cluster.modify(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.cluster.modify cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="modify_cluster",
        op_kwargs={
            "ClusterId": cluster_id,
            "StepConcurrencyLevel": step_concurrency_level,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, config_rule_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified AWS Config rule and all of its evaluation results. AWS Config sets the state of a rule to DELETING until the deletion is complete. You cannot update a rule while it is in this state. If you make a PutConfigRule or DeleteConfigRule request for the rule, you will receive a ResourceInUseException. You can check the state of a rule by using the DescribeConfigRules request.

    Args:
        config_rule_name(str): The name of the AWS Config rule that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.config.rule.init.delete(ctx, config_rule_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.config.rule.init.delete config_rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_config_rule",
        op_kwargs={"ConfigRuleName": config_rule_name},
    )


async def describe_all(
    hub, ctx, config_rule_names: List = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns details about your AWS Config rules.

    Args:
        config_rule_names(List, optional): The names of the AWS Config rules for which you want details. If you do not specify any names, AWS Config returns details for all your rules. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.config.rule.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.config.rule.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_config_rules",
        op_kwargs={"ConfigRuleNames": config_rule_names, "NextToken": next_token},
    )


async def put(hub, ctx, config_rule: Dict, tags: List = None) -> None:
    r"""
    **Autogenerated function**

    Adds or updates an AWS Config rule for evaluating whether your AWS resources comply with your desired configurations. You can use this action for custom AWS Config rules and AWS managed Config rules. A custom AWS Config rule is a rule that you develop and maintain. An AWS managed Config rule is a customizable, predefined rule that AWS Config provides. If you are adding a new custom AWS Config rule, you must first create the AWS Lambda function that the rule invokes to evaluate your resources. When you use the PutConfigRule action to add the rule to AWS Config, you must specify the Amazon Resource Name (ARN) that AWS Lambda assigns to the function. Specify the ARN for the SourceIdentifier key. This key is part of the Source object, which is part of the ConfigRule object.  If you are adding an AWS managed Config rule, specify the rule's identifier for the SourceIdentifier key. To reference AWS managed Config rule identifiers, see About AWS Managed Config Rules. For any new rule that you add, specify the ConfigRuleName in the ConfigRule object. Do not specify the ConfigRuleArn or the ConfigRuleId. These values are generated by AWS Config for new rules. If you are updating a rule that you added previously, you can specify the rule by ConfigRuleName, ConfigRuleId, or ConfigRuleArn in the ConfigRule data type that you use in this request. The maximum number of rules that AWS Config supports is 150. For information about requesting a rule limit increase, see AWS Config Limits in the AWS General Reference Guide. For more information about developing and using AWS Config rules, see Evaluating AWS Resource Configurations with AWS Config in the AWS Config Developer Guide.

    Args:
        config_rule(Dict): The rule that you want to add to your account.
        tags(List, optional): An array of tag object. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.config.rule.init.put(ctx, config_rule=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.config.rule.init.put config_rule=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_config_rule",
        op_kwargs={"ConfigRule": config_rule, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    delivery_stream_name: str,
    current_delivery_stream_version_id: str,
    destination_id: str,
    s3_destination_update: Dict = None,
    extended_s3_destination_update: Dict = None,
    redshift_destination_update: Dict = None,
    elasticsearch_destination_update: Dict = None,
    splunk_destination_update: Dict = None,
    http_endpoint_destination_update: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified destination of the specified delivery stream. Use this operation to change the destination type (for example, to replace the Amazon S3 destination with Amazon Redshift) or change the parameters associated with a destination (for example, to change the bucket name of the Amazon S3 destination). The update might not occur immediately. The target delivery stream remains active while the configurations are updated, so data writes to the delivery stream can continue during this process. The updated configurations are usually effective within a few minutes. Switching between Amazon ES and other services is not supported. For an Amazon ES destination, you can only update to another Amazon ES destination. If the destination type is the same, Kinesis Data Firehose merges the configuration parameters specified with the destination configuration that already exists on the delivery stream. If any of the parameters are not specified in the call, the existing values are retained. For example, in the Amazon S3 destination, if EncryptionConfiguration is not specified, then the existing EncryptionConfiguration is maintained on the destination. If the destination type is not the same, for example, changing the destination from Amazon S3 to Amazon Redshift, Kinesis Data Firehose does not merge any parameters. In this case, all parameters must be specified. Kinesis Data Firehose uses CurrentDeliveryStreamVersionId to avoid race conditions and conflicting merges. This is a required field, and the service updates the configuration only if the existing configuration has a version ID that matches. After the update is applied successfully, the version ID is updated, and can be retrieved using DescribeDeliveryStream. Use the new version ID to set CurrentDeliveryStreamVersionId in the next call.

    Args:
        delivery_stream_name(str): The name of the delivery stream.
        current_delivery_stream_version_id(str): Obtain this value from the VersionId result of DeliveryStreamDescription. This value is required, and helps the service perform conditional operations. For example, if there is an interleaving update and this value is null, then the update destination fails. After the update is successful, the VersionId value is updated. The service then performs a merge of the old configuration with the new configuration.
        destination_id(str): The ID of the destination.
        s3_destination_update(Dict, optional): [Deprecated] Describes an update for a destination in Amazon S3. Defaults to None.
        extended_s3_destination_update(Dict, optional): Describes an update for a destination in Amazon S3. Defaults to None.
        redshift_destination_update(Dict, optional): Describes an update for a destination in Amazon Redshift. Defaults to None.
        elasticsearch_destination_update(Dict, optional): Describes an update for a destination in Amazon ES. Defaults to None.
        splunk_destination_update(Dict, optional): Describes an update for a destination in Splunk. Defaults to None.
        http_endpoint_destination_update(Dict, optional): Describes an update to the specified HTTP endpoint destination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.destination.update(
                ctx,
                delivery_stream_name=value,
                current_delivery_stream_version_id=value,
                destination_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.destination.update delivery_stream_name=value, current_delivery_stream_version_id=value, destination_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="update_destination",
        op_kwargs={
            "DeliveryStreamName": delivery_stream_name,
            "CurrentDeliveryStreamVersionId": current_delivery_stream_version_id,
            "DestinationId": destination_id,
            "S3DestinationUpdate": s3_destination_update,
            "ExtendedS3DestinationUpdate": extended_s3_destination_update,
            "RedshiftDestinationUpdate": redshift_destination_update,
            "ElasticsearchDestinationUpdate": elasticsearch_destination_update,
            "SplunkDestinationUpdate": splunk_destination_update,
            "HttpEndpointDestinationUpdate": http_endpoint_destination_update,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, rest_api_id: str, stage_name: str, sdk_type: str, parameters: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a client SDK for a RestApi and Stage.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        stage_name(str): [Required] The name of the Stage that the SDK will use.
        sdk_type(str): [Required] The language for the generated SDK. Currently java, javascript, android, objectivec (for iOS), swift (for iOS), and ruby are supported.
        parameters(Dict, optional): A string-to-string key-value map of query parameters sdkType-dependent properties of the SDK. For sdkType of objectivec or swift, a parameter named classPrefix is required. For sdkType of android, parameters named groupId, artifactId, artifactVersion, and invokerPackage are required. For sdkType of java, parameters named serviceName and javaPackageName are required. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.sdk.init.get(
                ctx, rest_api_id=value, stage_name=value, sdk_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.sdk.init.get rest_api_id=value, stage_name=value, sdk_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_sdk",
        op_kwargs={
            "restApiId": rest_api_id,
            "stageName": stage_name,
            "sdkType": sdk_type,
            "parameters": parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    delivery_stream_name: str,
    delivery_stream_type: str = None,
    kinesis_stream_source_configuration: Dict = None,
    delivery_stream_encryption_configuration_input: Dict = None,
    s3_destination_configuration: Dict = None,
    extended_s3_destination_configuration: Dict = None,
    redshift_destination_configuration: Dict = None,
    elasticsearch_destination_configuration: Dict = None,
    splunk_destination_configuration: Dict = None,
    http_endpoint_destination_configuration: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Kinesis Data Firehose delivery stream. By default, you can create up to 50 delivery streams per AWS Region. This is an asynchronous operation that immediately returns. The initial status of the delivery stream is CREATING. After the delivery stream is created, its status is ACTIVE and it now accepts data. If the delivery stream creation fails, the status transitions to CREATING_FAILED. Attempts to send data to a delivery stream that is not in the ACTIVE state cause an exception. To check the state of a delivery stream, use DescribeDeliveryStream. If the status of a delivery stream is CREATING_FAILED, this status doesn't change, and you can't invoke CreateDeliveryStream again on it. However, you can invoke the DeleteDeliveryStream operation to delete it. A Kinesis Data Firehose delivery stream can be configured to receive records directly from providers using PutRecord or PutRecordBatch, or it can be configured to use an existing Kinesis stream as its source. To specify a Kinesis data stream as input, set the DeliveryStreamType parameter to KinesisStreamAsSource, and provide the Kinesis stream Amazon Resource Name (ARN) and role ARN in the KinesisStreamSourceConfiguration parameter. To create a delivery stream with server-side encryption (SSE) enabled, include DeliveryStreamEncryptionConfigurationInput in your request. This is optional. You can also invoke StartDeliveryStreamEncryption to turn on SSE for an existing delivery stream that doesn't have SSE enabled. A delivery stream is configured with a single destination: Amazon S3, Amazon ES, Amazon Redshift, or Splunk. You must specify only one of the following destination configuration parameters: ExtendedS3DestinationConfiguration, S3DestinationConfiguration, ElasticsearchDestinationConfiguration, RedshiftDestinationConfiguration, or SplunkDestinationConfiguration. When you specify S3DestinationConfiguration, you can also provide the following optional values: BufferingHints, EncryptionConfiguration, and CompressionFormat. By default, if no BufferingHints value is provided, Kinesis Data Firehose buffers data up to 5 MB or for 5 minutes, whichever condition is satisfied first. BufferingHints is a hint, so there are some cases where the service cannot adhere to these conditions strictly. For example, record boundaries might be such that the size is a little over or under the configured buffering size. By default, no encryption is performed. We strongly recommend that you enable encryption to ensure secure data storage in Amazon S3. A few notes about Amazon Redshift as a destination:   An Amazon Redshift destination requires an S3 bucket as intermediate location. Kinesis Data Firehose first delivers data to Amazon S3 and then uses COPY syntax to load data into an Amazon Redshift table. This is specified in the RedshiftDestinationConfiguration.S3Configuration parameter.   The compression formats SNAPPY or ZIP cannot be specified in RedshiftDestinationConfiguration.S3Configuration because the Amazon Redshift COPY operation that reads from the S3 bucket doesn't support these compression formats.   We strongly recommend that you use the user name and password you provide exclusively with Kinesis Data Firehose, and that the permissions for the account are restricted for Amazon Redshift INSERT permissions.   Kinesis Data Firehose assumes the IAM role that is configured as part of the destination. The role should allow the Kinesis Data Firehose principal to assume the role, and the role should have permissions that allow the service to deliver the data. For more information, see Grant Kinesis Data Firehose Access to an Amazon S3 Destination in the Amazon Kinesis Data Firehose Developer Guide.

    Args:
        delivery_stream_name(str): The name of the delivery stream. This name must be unique per AWS account in the same AWS Region. If the delivery streams are in different accounts or different Regions, you can have multiple delivery streams with the same name.
        delivery_stream_type(str, optional): The delivery stream type. This parameter can be one of the following values:    DirectPut: Provider applications access the delivery stream directly.    KinesisStreamAsSource: The delivery stream uses a Kinesis data stream as a source.  . Defaults to None.
        kinesis_stream_source_configuration(Dict, optional): When a Kinesis data stream is used as the source for the delivery stream, a KinesisStreamSourceConfiguration containing the Kinesis data stream Amazon Resource Name (ARN) and the role ARN for the source stream. Defaults to None.
        delivery_stream_encryption_configuration_input(Dict, optional): Used to specify the type and Amazon Resource Name (ARN) of the KMS key needed for Server-Side Encryption (SSE). Defaults to None.
        s3_destination_configuration(Dict, optional): [Deprecated] The destination in Amazon S3. You can specify only one destination. Defaults to None.
        extended_s3_destination_configuration(Dict, optional): The destination in Amazon S3. You can specify only one destination. Defaults to None.
        redshift_destination_configuration(Dict, optional): The destination in Amazon Redshift. You can specify only one destination. Defaults to None.
        elasticsearch_destination_configuration(Dict, optional): The destination in Amazon ES. You can specify only one destination. Defaults to None.
        splunk_destination_configuration(Dict, optional): The destination in Splunk. You can specify only one destination. Defaults to None.
        http_endpoint_destination_configuration(Dict, optional): Enables configuring Kinesis Firehose to deliver data to any HTTP endpoint destination. You can specify only one destination. Defaults to None.
        tags(List, optional): A set of tags to assign to the delivery stream. A tag is a key-value pair that you can define and assign to AWS resources. Tags are metadata. For example, you can add friendly names and descriptions or other types of information that can help you distinguish the delivery stream. For more information about tags, see Using Cost Allocation Tags in the AWS Billing and Cost Management User Guide. You can specify up to 50 tags when creating a delivery stream. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.delivery_stream.init.create(
                ctx, delivery_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.delivery_stream.init.create delivery_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="create_delivery_stream",
        op_kwargs={
            "DeliveryStreamName": delivery_stream_name,
            "DeliveryStreamType": delivery_stream_type,
            "KinesisStreamSourceConfiguration": kinesis_stream_source_configuration,
            "DeliveryStreamEncryptionConfigurationInput": delivery_stream_encryption_configuration_input,
            "S3DestinationConfiguration": s3_destination_configuration,
            "ExtendedS3DestinationConfiguration": extended_s3_destination_configuration,
            "RedshiftDestinationConfiguration": redshift_destination_configuration,
            "ElasticsearchDestinationConfiguration": elasticsearch_destination_configuration,
            "SplunkDestinationConfiguration": splunk_destination_configuration,
            "HttpEndpointDestinationConfiguration": http_endpoint_destination_configuration,
            "Tags": tags,
        },
    )


async def delete(
    hub, ctx, delivery_stream_name: str, allow_force_delete: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a delivery stream and its data. To check the state of a delivery stream, use DescribeDeliveryStream. You can delete a delivery stream only if it is in one of the following states: ACTIVE, DELETING, CREATING_FAILED, or DELETING_FAILED. You can't delete a delivery stream that is in the CREATING state. While the deletion request is in process, the delivery stream is in the DELETING state. While the delivery stream is in the DELETING state, the service might continue to accept records, but it doesn't make any guarantees with respect to delivering the data. Therefore, as a best practice, first stop any applications that are sending records before you delete a delivery stream.

    Args:
        delivery_stream_name(str): The name of the delivery stream.
        allow_force_delete(bool, optional): Set this to true if you want to delete the delivery stream even if Kinesis Data Firehose is unable to retire the grant for the CMK. Kinesis Data Firehose might be unable to retire the grant due to a customer error, such as when the CMK or the grant are in an invalid state. If you force deletion, you can then use the RevokeGrant operation to revoke the grant you gave to Kinesis Data Firehose. If a failure to retire the grant happens due to an AWS KMS issue, Kinesis Data Firehose keeps retrying the delete operation. The default value is false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.delivery_stream.init.delete(
                ctx, delivery_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.delivery_stream.init.delete delivery_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="delete_delivery_stream",
        op_kwargs={
            "DeliveryStreamName": delivery_stream_name,
            "AllowForceDelete": allow_force_delete,
        },
    )


async def describe(
    hub,
    ctx,
    delivery_stream_name: str,
    limit: int = None,
    exclusive_start_destination_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified delivery stream and its status. For example, after your delivery stream is created, call DescribeDeliveryStream to see whether the delivery stream is ACTIVE and therefore ready for data to be sent to it.  If the status of a delivery stream is CREATING_FAILED, this status doesn't change, and you can't invoke CreateDeliveryStream again on it. However, you can invoke the DeleteDeliveryStream operation to delete it. If the status is DELETING_FAILED, you can force deletion by invoking DeleteDeliveryStream again but with DeleteDeliveryStreamInput$AllowForceDelete set to true.

    Args:
        delivery_stream_name(str): The name of the delivery stream.
        limit(int, optional): The limit on the number of destinations to return. You can have one destination per delivery stream. Defaults to None.
        exclusive_start_destination_id(str, optional): The ID of the destination to start returning the destination information. Kinesis Data Firehose supports one destination per delivery stream. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.delivery_stream.init.describe(
                ctx, delivery_stream_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.delivery_stream.init.describe delivery_stream_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="describe_delivery_stream",
        op_kwargs={
            "DeliveryStreamName": delivery_stream_name,
            "Limit": limit,
            "ExclusiveStartDestinationId": exclusive_start_destination_id,
        },
    )


async def list_all(
    hub,
    ctx,
    limit: int = None,
    delivery_stream_type: str = None,
    exclusive_start_delivery_stream_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists your delivery streams in alphabetical order of their names. The number of delivery streams might be too large to return using a single call to ListDeliveryStreams. You can limit the number of delivery streams returned, using the Limit parameter. To determine whether there are more delivery streams to list, check the value of HasMoreDeliveryStreams in the output. If there are more delivery streams to list, you can request them by calling this operation again and setting the ExclusiveStartDeliveryStreamName parameter to the name of the last delivery stream returned in the last call.

    Args:
        limit(int, optional): The maximum number of delivery streams to list. The default value is 10. Defaults to None.
        delivery_stream_type(str, optional): The delivery stream type. This can be one of the following values:    DirectPut: Provider applications access the delivery stream directly.    KinesisStreamAsSource: The delivery stream uses a Kinesis data stream as a source.   This parameter is optional. If this parameter is omitted, delivery streams of all types are returned. Defaults to None.
        exclusive_start_delivery_stream_name(str, optional): The list of delivery streams returned by this call to ListDeliveryStreams will start with the delivery stream whose name comes alphabetically immediately after the name you specify in ExclusiveStartDeliveryStreamName. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.delivery_stream.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.delivery_stream.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="list_delivery_streams",
        op_kwargs={
            "Limit": limit,
            "DeliveryStreamType": delivery_stream_type,
            "ExclusiveStartDeliveryStreamName": exclusive_start_delivery_stream_name,
        },
    )


async def tag(hub, ctx, delivery_stream_name: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds or updates tags for the specified delivery stream. A tag is a key-value pair that you can define and assign to AWS resources. If you specify a tag that already exists, the tag value is replaced with the value that you specify in the request. Tags are metadata. For example, you can add friendly names and descriptions or other types of information that can help you distinguish the delivery stream. For more information about tags, see Using Cost Allocation Tags in the AWS Billing and Cost Management User Guide.  Each delivery stream can have up to 50 tags.  This operation has a limit of five transactions per second per account.

    Args:
        delivery_stream_name(str): The name of the delivery stream to which you want to add the tags.
        tags(List): A set of key-value pairs to use to create the tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.delivery_stream.init.tag(
                ctx, delivery_stream_name=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.delivery_stream.init.tag delivery_stream_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="tag_delivery_stream",
        op_kwargs={"DeliveryStreamName": delivery_stream_name, "Tags": tags},
    )


async def untag(hub, ctx, delivery_stream_name: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes tags from the specified delivery stream. Removed tags are deleted, and you can't recover them after this operation successfully completes. If you specify a tag that doesn't exist, the operation ignores it. This operation has a limit of five transactions per second per account.

    Args:
        delivery_stream_name(str): The name of the delivery stream.
        tag_keys(List): A list of tag keys. Each corresponding tag is removed from the delivery stream.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.delivery_stream.init.untag(
                ctx, delivery_stream_name=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.delivery_stream.init.untag delivery_stream_name=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="untag_delivery_stream",
        op_kwargs={"DeliveryStreamName": delivery_stream_name, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def start(hub, ctx, graph_arn: str, account_id: str) -> None:
    r"""
    **Autogenerated function**

    Sends a request to enable data ingest for a member account that has a status of ACCEPTED_BUT_DISABLED. For valid member accounts, the status is updated as follows.   If Detective enabled the member account, then the new status is ENABLED.   If Detective cannot enable the member account, the status remains ACCEPTED_BUT_DISABLED.

    Args:
        graph_arn(str): The ARN of the behavior graph.
        account_id(str): The account ID of the member account to try to enable. The account must be an invited member account with a status of ACCEPTED_BUT_DISABLED. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.monitoring_member.start(
                ctx, graph_arn=value, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.monitoring_member.start graph_arn=value, account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="start_monitoring_member",
        op_kwargs={"GraphArn": graph_arn, "AccountId": account_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, device_ids: List, tracker_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the position history of one or more devices from a tracker resource.

    Args:
        device_ids(List): Devices whose position history you want to delete.   For example, for two devices: “DeviceIds” : [DeviceId1,DeviceId2]   .
        tracker_name(str): The name of the tracker resource to delete the device position history from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.delete.device_position_history.batch(
                ctx, device_ids=value, tracker_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.delete.device_position_history.batch device_ids=value, tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="batch_delete_device_position_history",
        op_kwargs={"DeviceIds": device_ids, "TrackerName": tracker_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    second_snapshot_id: str,
    first_snapshot_id: str = None,
    next_token: str = None,
    max_results: int = None,
    starting_block_index: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the blocks that are different between two Amazon Elastic Block Store snapshots of the same volume/snapshot lineage.

    Args:
        first_snapshot_id(str, optional): The ID of the first snapshot to use for the comparison.  The FirstSnapshotID parameter must be specified with a SecondSnapshotId parameter; otherwise, an error occurs. . Defaults to None.
        second_snapshot_id(str): The ID of the second snapshot to use for the comparison.  The SecondSnapshotId parameter must be specified with a FirstSnapshotID parameter; otherwise, an error occurs. .
        next_token(str, optional): The token to request the next page of results. Defaults to None.
        max_results(int, optional): The number of results to return. Defaults to None.
        starting_block_index(int, optional): The block index from which the comparison should start. The list in the response will start from this block index or the next valid block index in the snapshots. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ebs.changed_block.list_all(ctx, second_snapshot_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ebs.changed_block.list_all second_snapshot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ebs",
        operation="list_changed_blocks",
        op_kwargs={
            "FirstSnapshotId": first_snapshot_id,
            "SecondSnapshotId": second_snapshot_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "StartingBlockIndex": starting_block_index,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    application_id: str,
    name: str,
    location_uri: str,
    description: str = None,
    retrieval_role_arn: str = None,
    validators: List = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Information that enables AppConfig to access the configuration source. Valid configuration sources include Systems Manager (SSM) documents, SSM Parameter Store parameters, and Amazon S3 objects. A configuration profile includes the following information.   The Uri location of the configuration data.   The AWS Identity and Access Management (IAM) role that provides access to the configuration data.   A validator for the configuration data. Available validators include either a JSON Schema or an AWS Lambda function.   For more information, see Create a Configuration and a Configuration Profile in the AWS AppConfig User Guide.

    Args:
        application_id(str): The application ID.
        name(str): A name for the configuration profile.
        description(str, optional): A description of the configuration profile. Defaults to None.
        location_uri(str): A URI to locate the configuration. You can specify a Systems Manager (SSM) document, an SSM Parameter Store parameter, or an Amazon S3 object. For an SSM document, specify either the document name in the format ssm-document://<Document_name> or the Amazon Resource Name (ARN). For a parameter, specify either the parameter name in the format ssm-parameter://<Parameter_name> or the ARN. For an Amazon S3 object, specify the URI in the following format: s3://<bucket>/<objectKey> . Here is an example: s3://my-bucket/my-app/us-east-1/my-config.json.
        retrieval_role_arn(str, optional): The ARN of an IAM role with permission to access the configuration at the specified LocationUri. Defaults to None.
        validators(List, optional): A list of methods for validating the configuration. Defaults to None.
        tags(Dict, optional): Metadata to assign to the configuration profile. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.configuration.profile.create(
                ctx, application_id=value, name=value, location_uri=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.configuration.profile.create application_id=value, name=value, location_uri=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="create_configuration_profile",
        op_kwargs={
            "ApplicationId": application_id,
            "Name": name,
            "Description": description,
            "LocationUri": location_uri,
            "RetrievalRoleArn": retrieval_role_arn,
            "Validators": validators,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, application_id: str, configuration_profile_id: str) -> None:
    r"""
    **Autogenerated function**

    Delete a configuration profile. Deleting a configuration profile does not delete a configuration from a host.

    Args:
        application_id(str): The application ID that includes the configuration profile you want to delete.
        configuration_profile_id(str): The ID of the configuration profile you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.configuration.profile.delete(
                ctx, application_id=value, configuration_profile_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.configuration.profile.delete application_id=value, configuration_profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="delete_configuration_profile",
        op_kwargs={
            "ApplicationId": application_id,
            "ConfigurationProfileId": configuration_profile_id,
        },
    )


async def get(hub, ctx, application_id: str, configuration_profile_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve information about a configuration profile.

    Args:
        application_id(str): The ID of the application that includes the configuration profile you want to get.
        configuration_profile_id(str): The ID of the configuration profile you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.configuration.profile.get(
                ctx, application_id=value, configuration_profile_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.configuration.profile.get application_id=value, configuration_profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="get_configuration_profile",
        op_kwargs={
            "ApplicationId": application_id,
            "ConfigurationProfileId": configuration_profile_id,
        },
    )


async def list_all(
    hub, ctx, application_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the configuration profiles for an application.

    Args:
        application_id(str): The application ID.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.configuration.profile.list_all(
                ctx, application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.configuration.profile.list_all application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="list_configuration_profiles",
        op_kwargs={
            "ApplicationId": application_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    application_id: str,
    configuration_profile_id: str,
    name: str = None,
    description: str = None,
    retrieval_role_arn: str = None,
    validators: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a configuration profile.

    Args:
        application_id(str): The application ID.
        configuration_profile_id(str): The ID of the configuration profile.
        name(str, optional): The name of the configuration profile. Defaults to None.
        description(str, optional): A description of the configuration profile. Defaults to None.
        retrieval_role_arn(str, optional): The ARN of an IAM role with permission to access the configuration at the specified LocationUri. Defaults to None.
        validators(List, optional): A list of methods for validating the configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appconfig.configuration.profile.update(
                ctx, application_id=value, configuration_profile_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appconfig.configuration.profile.update application_id=value, configuration_profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appconfig",
        operation="update_configuration_profile",
        op_kwargs={
            "ApplicationId": application_id,
            "ConfigurationProfileId": configuration_profile_id,
            "Name": name,
            "Description": description,
            "RetrievalRoleArn": retrieval_role_arn,
            "Validators": validators,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, job_flow_ids: List, visible_to_all_users: bool) -> None:
    r"""
    **Autogenerated function**

    Sets the Cluster$VisibleToAllUsers value for an EMR cluster. When true, IAM principals in the account can perform EMR cluster actions that their IAM policies allow. When false, only the IAM principal that created the cluster and the account root user can perform EMR actions on the cluster, regardless of IAM permissions policies attached to other IAM principals. This action works on running clusters. When you create a cluster, use the RunJobFlowInput$VisibleToAllUsers parameter. For more information, see Understanding the EMR Cluster VisibleToAllUsers Setting in the Amazon EMR Management Guide.

    Args:
        job_flow_ids(List): The unique identifier of the job flow (cluster).
        visible_to_all_users(bool): A value of true indicates that an IAM principal in the account can perform EMR actions on the cluster that the IAM policies attached to the principal allow. A value of false indicates that only the IAM principal that created the cluster and the Amazon Web Services root user can perform EMR actions on the cluster.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.visible_to_all_user.set(
                ctx, job_flow_ids=value, visible_to_all_users=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.visible_to_all_user.set job_flow_ids=value, visible_to_all_users=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="set_visible_to_all_users",
        op_kwargs={
            "JobFlowIds": job_flow_ids,
            "VisibleToAllUsers": visible_to_all_users,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, resolver_rule_id: str, vpc_id: str, name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a Resolver rule with a VPC. When you associate a rule with a VPC, Resolver forwards all DNS queries for the domain name that is specified in the rule and that originate in the VPC. The queries are forwarded to the IP addresses for the DNS resolvers that are specified in the rule. For more information about rules, see CreateResolverRule.

    Args:
        resolver_rule_id(str): The ID of the Resolver rule that you want to associate with the VPC. To list the existing Resolver rules, use ListResolverRules.
        name(str, optional): A name for the association that you're creating between a Resolver rule and a VPC. Defaults to None.
        vpc_id(str): The ID of the VPC that you want to associate the Resolver rule with.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.init.associate(
                ctx, resolver_rule_id=value, vpc_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.init.associate resolver_rule_id=value, vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="associate_resolver_rule",
        op_kwargs={"ResolverRuleId": resolver_rule_id, "Name": name, "VPCId": vpc_id},
    )


async def create(
    hub,
    ctx,
    creator_request_id: str,
    rule_type: str,
    domain_name: str,
    name: str = None,
    target_ips: List = None,
    resolver_endpoint_id: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network.

    Args:
        creator_request_id(str): A unique string that identifies the request and that allows failed requests to be retried without the risk of running the operation twice. CreatorRequestId can be any unique string, for example, a date/time stamp. .
        name(str, optional): A friendly name that lets you easily find a rule in the Resolver dashboard in the Route 53 console. Defaults to None.
        rule_type(str): When you want to forward DNS queries for specified domain name to resolvers on your network, specify FORWARD. When you have a forwarding rule to forward DNS queries for a domain to your network and you want Resolver to process queries for a subdomain of that domain, specify SYSTEM. For example, to forward DNS queries for example.com to resolvers on your network, you create a rule and specify FORWARD for RuleType. To then have Resolver process queries for apex.example.com, you create a rule and specify SYSTEM for RuleType. Currently, only Resolver can create rules that have a value of RECURSIVE for RuleType.
        domain_name(str): DNS queries for this domain name are forwarded to the IP addresses that you specify in TargetIps. If a query matches multiple Resolver rules (example.com and www.example.com), outbound DNS queries are routed using the Resolver rule that contains the most specific domain name (www.example.com).
        target_ips(List, optional): The IPs that you want Resolver to forward DNS queries to. You can specify only IPv4 addresses. Separate IP addresses with a space.  TargetIps is available only when the value of Rule type is FORWARD. Defaults to None.
        resolver_endpoint_id(str, optional): The ID of the outbound Resolver endpoint that you want to use to route DNS queries to the IP addresses that you specify in TargetIps. Defaults to None.
        tags(List, optional): A list of the tag keys and values that you want to associate with the endpoint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.init.create(
                ctx, creator_request_id=value, rule_type=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.init.create creator_request_id=value, rule_type=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="create_resolver_rule",
        op_kwargs={
            "CreatorRequestId": creator_request_id,
            "Name": name,
            "RuleType": rule_type,
            "DomainName": domain_name,
            "TargetIps": target_ips,
            "ResolverEndpointId": resolver_endpoint_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, resolver_rule_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Resolver rule. Before you can delete a Resolver rule, you must disassociate it from all the VPCs that you associated the Resolver rule with. For more information, see DisassociateResolverRule.

    Args:
        resolver_rule_id(str): The ID of the Resolver rule that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.init.delete(
                ctx, resolver_rule_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.init.delete resolver_rule_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="delete_resolver_rule",
        op_kwargs={"ResolverRuleId": resolver_rule_id},
    )


async def disassociate(hub, ctx, vpc_id: str, resolver_rule_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the association between a specified Resolver rule and a specified VPC.  If you disassociate a Resolver rule from a VPC, Resolver stops forwarding DNS queries for the domain name that you specified in the Resolver rule.

    Args:
        vpc_id(str): The ID of the VPC that you want to disassociate the Resolver rule from.
        resolver_rule_id(str): The ID of the Resolver rule that you want to disassociate from the specified VPC.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.init.disassociate(
                ctx, vpc_id=value, resolver_rule_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.init.disassociate vpc_id=value, resolver_rule_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="disassociate_resolver_rule",
        op_kwargs={"VPCId": vpc_id, "ResolverRuleId": resolver_rule_id},
    )


async def get(hub, ctx, resolver_rule_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the ID of the outbound Resolver endpoint that the rule is associated with.

    Args:
        resolver_rule_id(str): The ID of the Resolver rule that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.init.get(
                ctx, resolver_rule_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.init.get resolver_rule_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_resolver_rule",
        op_kwargs={"ResolverRuleId": resolver_rule_id},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Resolver rules that were created using the current AWS account.

    Args:
        max_results(int, optional): The maximum number of Resolver rules that you want to return in the response to a ListResolverRules request. If you don't specify a value for MaxResults, Resolver returns up to 100 Resolver rules. Defaults to None.
        next_token(str, optional): For the first ListResolverRules request, omit this value. If you have more than MaxResults Resolver rules, you can submit another ListResolverRules request to get the next group of Resolver rules. In the next request, specify the value of NextToken from the previous response. . Defaults to None.
        filters(List, optional): An optional specification to return a subset of Resolver rules, such as all Resolver rules that are associated with the same Resolver endpoint.  If you submit a second or subsequent ListResolverRules request and specify the NextToken parameter, you must use the same values for Filters, if any, as in the previous request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_resolver_rules",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )


async def update(hub, ctx, resolver_rule_id: str, config: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates settings for a specified Resolver rule. ResolverRuleId is required, and all other parameters are optional. If you don't specify a parameter, it retains its current value.

    Args:
        resolver_rule_id(str): The ID of the Resolver rule that you want to update.
        config(Dict): The new settings for the Resolver rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.rule.init.update(
                ctx, resolver_rule_id=value, config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.rule.init.update resolver_rule_id=value, config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="update_resolver_rule",
        op_kwargs={"ResolverRuleId": resolver_rule_id, "Config": config},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified tags to a resource with the specified resourceArn. If existing tags on a resource aren't specified in the request parameters, they aren't changed. When a resource is deleted, the tags that are associated with that resource are deleted as well. Batch resources that support tags are compute environments, jobs, job definitions, and job queues. ARNs for child jobs of array and multi-node parallel (MNP) jobs are not supported.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource that tags are added to. Batch resources that support tags are compute environments, jobs, job definitions, and job queues. ARNs for child jobs of array and multi-node parallel (MNP) jobs are not supported.
        tags(Dict): The tags that you apply to the resource to help you categorize and organize your resources. Each tag consists of a key and an optional value. For more information, see Tagging Amazon Web Services Resources in Amazon Web Services General Reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes specified tags from an Batch resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource from which to delete tags. Batch resources that support tags are compute environments, jobs, job definitions, and job queues. ARNs for child jobs of array and multi-node parallel (MNP) jobs are not supported.
        tag_keys(List): The keys of the tags to be removed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    template_name: str,
    template_body: str,
    provisioning_role_arn: str,
    description: str = None,
    enabled: bool = None,
    pre_provisioning_hook: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a fleet provisioning template.

    Args:
        template_name(str): The name of the fleet provisioning template.
        description(str, optional): The description of the fleet provisioning template. Defaults to None.
        template_body(str): The JSON formatted contents of the fleet provisioning template.
        enabled(bool, optional): True to enable the fleet provisioning template, otherwise false. Defaults to None.
        provisioning_role_arn(str): The role ARN for the role associated with the fleet provisioning template. This IoT role grants permission to provision a device.
        pre_provisioning_hook(Dict, optional): Creates a pre-provisioning hook template. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the fleet provisioning template.  For URI Request parameters use format: ...key1=value1&key2=value2... For the CLI command-line parameter use format: &&tags "key1=value1&key2=value2..." For the cli-input-json file use format: "tags": "key1=value1&key2=value2..." . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.provisioning.template.init.create(
                ctx, template_name=value, template_body=value, provisioning_role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.provisioning.template.init.create template_name=value, template_body=value, provisioning_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_provisioning_template",
        op_kwargs={
            "templateName": template_name,
            "description": description,
            "templateBody": template_body,
            "enabled": enabled,
            "provisioningRoleArn": provisioning_role_arn,
            "preProvisioningHook": pre_provisioning_hook,
            "tags": tags,
        },
    )


async def delete(hub, ctx, template_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a fleet provisioning template.

    Args:
        template_name(str): The name of the fleet provision template to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.provisioning.template.init.delete(ctx, template_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.provisioning.template.init.delete template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_provisioning_template",
        op_kwargs={"templateName": template_name},
    )


async def describe(hub, ctx, template_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a fleet provisioning template.

    Args:
        template_name(str): The name of the fleet provisioning template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.provisioning.template.init.describe(
                ctx, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.provisioning.template.init.describe template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_provisioning_template",
        op_kwargs={"templateName": template_name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the fleet provisioning templates in your AWS account.

    Args:
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.
        next_token(str, optional): A token to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.provisioning.template.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.provisioning.template.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_provisioning_templates",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    template_name: str,
    description: str = None,
    enabled: bool = None,
    default_version_id: int = None,
    provisioning_role_arn: str = None,
    pre_provisioning_hook: Dict = None,
    remove_pre_provisioning_hook: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a fleet provisioning template.

    Args:
        template_name(str): The name of the fleet provisioning template.
        description(str, optional): The description of the fleet provisioning template. Defaults to None.
        enabled(bool, optional): True to enable the fleet provisioning template, otherwise false. Defaults to None.
        default_version_id(int, optional): The ID of the default provisioning template version. Defaults to None.
        provisioning_role_arn(str, optional): The ARN of the role associated with the provisioning template. This IoT role grants permission to provision a device. Defaults to None.
        pre_provisioning_hook(Dict, optional): Updates the pre-provisioning hook template. Defaults to None.
        remove_pre_provisioning_hook(bool, optional): Removes pre-provisioning hook template. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.provisioning.template.init.update(ctx, template_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.provisioning.template.init.update template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_provisioning_template",
        op_kwargs={
            "templateName": template_name,
            "description": description,
            "enabled": enabled,
            "defaultVersionId": default_version_id,
            "provisioningRoleArn": provisioning_role_arn,
            "preProvisioningHook": pre_provisioning_hook,
            "removePreProvisioningHook": remove_pre_provisioning_hook,
        },
    )
